[tor-commits] [stem/master] New circuit purposes
atagar at torproject.org
atagar at torproject.org
Fri Aug 21 01:23:42 UTC 2020
commit 3f67d82f84cfd9792c91059eef9252755f9d50ee
Author: Damian Johnson <atagar at torproject.org>
Date: Thu Aug 20 18:10:45 2020 -0700
New circuit purposes
Added by https://gitweb.torproject.org/torspec.git/commit/?id=a9fee22
---
stem/__init__.py | 33 +++++++++++++++++++++------------
1 file changed, 21 insertions(+), 12 deletions(-)
diff --git a/stem/__init__.py b/stem/__init__.py
index 49e9ce14..228ec7be 100644
--- a/stem/__init__.py
+++ b/stem/__init__.py
@@ -141,18 +141,24 @@ Library for working with the tor process.
Description of what a circuit is intended for. These were introduced in tor
version 0.2.1.6. Tor may provide purposes not in this enum.
- ==================== ===========
- CircPurpose Description
- ==================== ===========
- **GENERAL** client traffic or fetching directory information
- **HS_CLIENT_INTRO** client side introduction point for a hidden service circuit
- **HS_CLIENT_REND** client side hidden service rendezvous circuit
- **HS_SERVICE_INTRO** server side introduction point for a hidden service circuit
- **HS_SERVICE_REND** server side hidden service rendezvous circuit
- **TESTING** testing to see if we're reachable, so we can be used as a relay
- **CONTROLLER** circuit that was built by a controller
- **MEASURE_TIMEOUT** circuit being kept around to see how long it takes
- ==================== ===========
+ .. versionchanged:: 2.0.0
+ Added HS_VANGUARDS, PATH_BIAS_TESTING, and CIRCUIT_PADDING (:spec:`a9fee22`).
+
+ ======================= ===========
+ CircPurpose Description
+ ======================= ===========
+ **GENERAL** client traffic or fetching directory information
+ **HS_CLIENT_INTRO** client side introduction point for a hidden service circuit
+ **HS_CLIENT_REND** client side hidden service rendezvous circuit
+ **HS_SERVICE_INTRO** server side introduction point for a hidden service circuit
+ **HS_SERVICE_REND** server side hidden service rendezvous circuit
+ **TESTING** testing to see if we're reachable, so we can be used as a relay
+ **CONTROLLER** circuit that was built by a controller
+ **MEASURE_TIMEOUT** circuit being kept around to see how long it takes
+ **HS_VANGUARDS** constructed in advance for HS vanguards
+ **PATH_BIAS_TESTING** probing if circuits are being maliciously closed
+ **CIRCUIT_PADDING** circuit is unused, but remains open to disguise its closure time
+ ======================= ===========
.. data:: CircClosureReason (enum)
@@ -855,6 +861,9 @@ CircPurpose = stem.util.enum.UppercaseEnum(
'TESTING',
'CONTROLLER',
'MEASURE_TIMEOUT',
+ 'HS_VANGUARDS',
+ 'PATH_BIAS_TESTING',
+ 'CIRCUIT_PADDING',
)
CircClosureReason = stem.util.enum.UppercaseEnum(
More information about the tor-commits
mailing list